Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Resilience Hub Service.

Actions, resources, and condition keys for AWS Resilience Hub Service - Service Authorization Reference

# Actions, resources, and condition keys for AWS Resilience Hub Service

AWS Resilience Hub Service (service prefix: `resiliencehub` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by AWS Resilience Hub Service
- Resource types defined by AWS Resilience Hub Service
- Condition keys for AWS Resilience Hub Service

## Actions defined by AWS Resilience Hub Service

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AddDraftAppVersionResourceMappings | Grants permission to add draft application version resource mappings | Write | application* |  | cloudformation:DescribeStacks cloudformation:ListStackResources resource-groups:GetGroup resource-groups:ListGroupResources servicecatalog:GetApplication servicecatalog:ListAssociatedResources
CreateApp | Grants permission to create application | Write | resiliency-policy |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateRecommendationTemplate | Grants permission to create recommendation template | Write | application* |  | s3:CreateBucket s3:ListBucket s3:PutObject
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateResiliencyPolicy | Grants permission to create resiliency policy | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
DeleteApp | Grants permission to batch delete application | Write | application* |  |
DeleteAppAssessment | Grants permission to batch delete application assessment | Write | application* |  |
DeleteRecommendationTemplate | Grants permission to batch delete recommendation template | Write | application* |  |
DeleteResiliencyPolicy | Grants permission to batch delete resiliency policy | Write | resiliency-policy* |  |
DescribeApp | Grants permission to describe application | Read | application* |  |
DescribeAppAssessment | Grants permission to describe application assessment | Read | application* |  |
DescribeAppVersionResourcesResolutionStatus | Grants permission to describe application resolution | Read | application* |  |
DescribeAppVersionTemplate | Grants permission to describe application version template | Read | application* |  |
DescribeDraftAppVersionResourcesImportStatus | Grants permission to describe draft application version resources import status | Read | application* |  |
DescribeResiliencyPolicy | Grants permission to describe resiliency policy | Read | resiliency-policy* |  |
ImportResourcesToDraftAppVersion | Grants permission to import resources to draft application version | Write | application* |  | cloudformation:DescribeStacks cloudformation:ListStackResources resource-groups:GetGroup resource-groups:ListGroupResources servicecatalog:GetApplication servicecatalog:ListAssociatedResources
ListAlarmRecommendations | Grants permission to list alarm recommendation | List | application* |  |
ListAppAssessments | Grants permission to list application assessment | List | application |  |
ListAppComponentCompliances | Grants permission to list app component compliances | List | application* |  |
ListAppComponentRecommendations | Grants permission to list app component recommendations | List | application* |  |
ListAppVersionResourceMappings | Grants permission to application version resource mappings | List | application* |  |
ListAppVersionResources | Grants permission to list application resources | List | application* |  |
ListAppVersions | Grants permission to list application version | List | application* |  |
ListApps | Grants permission to list applications | List |  |  |
ListRecommendationTemplates | Grants permission to list recommendation templates | List | application* |  |
ListResiliencyPolicies | Grants permission to list resiliency policies | List |  |  |
ListSopRecommendations | Grants permission to list SOP recommendations | List | application* |  |
ListSuggestedResiliencyPolicies | Grants permission to list suggested resiliency policies | List |  |  |
ListTagsForResource | Grants permission to list tags for a resource | Read |  |  |
ListTestRecommendations | Grants permission to list test recommendations | List | application* |  |
ListUnsupportedAppVersionResources | Grants permission to list unsupported application version resources | List | application* |  |
PublishAppVersion | Grants permission to publish application version | Write | application* |  |
PutDraftAppVersionTemplate | Grants permission to put draft application version template | Write | application* |  |
RemoveDraftAppVersionResourceMappings | Grants permission to remove draft application version mappings | Write | application* |  |
ResolveAppVersionResources | Grants permission to resolve application version resources | Write | application* |  | cloudformation:DescribeStacks cloudformation:ListStackResources resource-groups:GetGroup resource-groups:ListGroupResources servicecatalog:GetApplication servicecatalog:ListAssociatedResources
StartAppAssessment | Grants permission to create application assessment | Write | application* |  | cloudformation:DescribeStacks cloudformation:ListStackResources cloudwatch:DescribeAlarms cloudwatch:GetMetricData cloudwatch:GetMetricStatistics cloudwatch:PutMetricData fis:GetExperimentTemplate fis:ListExperimentTemplates fis:ListExperiments resource-groups:GetGroup resource-groups:ListGroupResources servicecatalog:GetApplication servicecatalog:ListAssociatedResources ssm:GetParametersByPath
| aws:RequestTag/${TagKey} aws:TagKeys |
TagResource | Grants permission to assign a resource tag | Tagging | app-assessment |  |
application |  |
recommendation-template |  |
resiliency-policy |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | Grants permission to untag a resource | Tagging | app-assessment |  |
application |  |
recommendation-template |  |
resiliency-policy |  |
| aws:TagKeys |
UpdateApp | Grants permission to update application | Write | application* |  |
UpdateResiliencyPolicy | Grants permission to update resiliency policy | Write | resiliency-policy* |  |

## Resource types defined by AWS Resilience Hub Service

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
resiliency-policy | `arn:$ { Partition}:resiliencehub:$ { Region}:$ { Account}:resiliency-policy/$ { ResiliencyPolicyID}` | aws:ResourceTag/${TagKey}
application | `arn:$ { Partition}:resiliencehub:$ { Region}:$ { Account}:app/$ { AppID}` | aws:ResourceTag/${TagKey}
app-assessment | `arn:$ { Partition}:resiliencehub:$ { Region}:$ { Account}:app-assessment/$ { AppAssessmentID}` | aws:ResourceTag/${TagKey}
recommendation-template | `arn:$ { Partition}:resiliencehub:$ { Region}:$ { Account}:recommendation-template/$ { RecommendationTemplateID}` | aws:ResourceTag/${TagKey}

## Condition keys for AWS Resilience Hub Service

AWS Resilience Hub Service defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by the presence of tag key-value pairs in the request | String
aws:ResourceTag/${TagKey} | Filters access by tag key-value pairs attached to the resource | String
aws:TagKeys | Filters access by the tag keys that are passed in the request | ArrayOfString

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.